@@ -38,8 +38,10 @@ Demons_state::init (
     } else {
 	/* Otherwise initialize to zero */
 	vf_smooth = new Volume (fixed->dim, fixed->offset, fixed->spacing, 
-	    fixed->direction_cosines, PT_VF_FLOAT_INTERLEAVED, 3);
+	    fixed->direction_cosines.m_direction_cosines, 
+	    PT_VF_FLOAT_INTERLEAVED, 3);
     }
     vf_est = new Volume (fixed->dim, fixed->offset, fixed->spacing, 
-	fixed->direction_cosines, PT_VF_FLOAT_INTERLEAVED, 3);
+	fixed->direction_cosines.m_direction_cosines, 
+	PT_VF_FLOAT_INTERLEAVED, 3);
 }
